@@ -7,7 +7,13 @@
 #include "iniparser.h"
 #include <fcntl.h>
 #include <cstdio>
+#include <functional>
+#include <string>
+#include <string_view>
+#include "fcitx-config/rawconfig.h"
 #include "fcitx-utils/fs.h"
+#include "fcitx-utils/macros.h"
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/standardpath.h"
 #include "fcitx-utils/stringutils.h"
 #include "fcitx-utils/unixfd.h"
@@ -42,26 +48,20 @@ bool writeAsIni(const RawConfig &config, int fd) {
 }
 
 void readFromIni(RawConfig &config, FILE *fin) {
-    std::string lineBuf, currentGroup;
+    std::string currentGroup;
 
     UniqueCPtr<char> clineBuf;
     size_t bufSize = 0;
     unsigned int line = 0;
     while (getline(clineBuf, &bufSize, fin) >= 0) {
         line++;
-        lineBuf = clineBuf.get();
-        auto pair = stringutils::trimInplace(lineBuf);
-        std::string::size_type start = pair.first, end = pair.second;
-        if (start == end || lineBuf[start] == '#') {
+        std::string_view lineBuf = stringutils::trimView(clineBuf.get());
+        if (lineBuf.empty() || lineBuf.front() == '#') {
             continue;
         }
 
-        lineBuf.resize(end);
-
-        std::string::size_type equalPos;
-
-        if (lineBuf[start] == '[' && lineBuf[end - 1] == ']') {
-            currentGroup = lineBuf.substr(start + 1, end - start - 2);
+        if (lineBuf.front() == '[' && lineBuf.back() == ']') {
+            currentGroup = lineBuf.substr(1, lineBuf.size() - 2);
             config.visitItemsOnPath(
                 [line](RawConfig &config, const std::string &) {
                     if (!config.lineNumber()) {
@@ -69,9 +69,9 @@ void readFromIni(RawConfig &config, FILE *fin) {
                     }
                 },
                 currentGroup);
-        } else if ((equalPos = lineBuf.find_first_of('=', start)) !=
-                   std::string::npos) {
-            auto name = lineBuf.substr(start, equalPos - start);
+        } else if (std::string::size_type equalPos = lineBuf.find_first_of('=');
+                   equalPos != std::string::npos) {
+            auto name = lineBuf.substr(0, equalPos);
             auto valueStart = equalPos + 1;
 
             auto value = stringutils::unescapeForValue(
@@ -87,7 +87,7 @@ void readFromIni(RawConfig &config, FILE *fin) {
                 s += name;
                 subConfig = config.get(s, true);
             } else {
-                subConfig = config.get(name, true);
+                subConfig = config.get(std::string(name), true);
             }
             subConfig->setValue(*value);
             subConfig->setLineNumber(line);
@@ -95,7 +95,7 @@ void readFromIni(RawConfig &config, FILE *fin) {
     }
 }
 
-bool writeAsIni(const RawConfig &root, FILE *fout) {
+bool writeAsIni(const RawConfig &config, FILE *fout) {
     std::function<bool(const RawConfig &, const std::string &path)> callback;
 
     callback = [fout, &callback](const RawConfig &config,
@@ -122,13 +122,12 @@ bool writeAsIni(const RawConfig &root, FILE *fout) {
                     return true;
                 },
                 "", false, path);
-            auto valueString = values;
-            if (!valueString.empty()) {
+            if (!values.empty()) {
                 if (!path.empty()) {
                     FCITX_RETURN_IF(fprintf(fout, "[%s]\n", path.c_str()) < 0,
                                     false);
                 }
-                FCITX_RETURN_IF(fprintf(fout, "%s\n", valueString.c_str()) < 0,
+                FCITX_RETURN_IF(fprintf(fout, "%s\n", values.c_str()) < 0,
                                 false);
             }
         }
@@ -136,7 +135,7 @@ bool writeAsIni(const RawConfig &root, FILE *fout) {
         return true;
     };
 
-    return callback(root, "");
+    return callback(config, "");
 }
 
 void readAsIni(RawConfig &rawConfig, const std::string &path) {
