@@ -14,12 +14,10 @@
 #include "fcitx-utils/dbus/message_details.h"
 #include "fcitx-utils/misc_p.h"
 #include "fcitx-utils/standardpath.h"
-#include "fcitx-utils/utf8.h"
 #include "fcitx/event.h"
 #include "fcitx/inputcontext.h"
 #include "fcitx/inputcontextmanager.h"
 #include "fcitx/instance.h"
-#include "fcitx/userinterfacemanager.h"
 #include "common.h"
 #include "notificationitem_public.h"
 #include "plasmathemewatchdog.h"
@@ -492,7 +490,7 @@ void ClassicUI::setSubConfig(const std::string &path,
 std::vector<unsigned char> ClassicUI::labelIcon(const std::string &label,
                                                 unsigned int size) {
     std::vector<unsigned char> data;
-    auto stride = cairo_format_stride_for_width(CAIRO_FORMAT_ARGB32, size);
+    size_t stride = cairo_format_stride_for_width(CAIRO_FORMAT_ARGB32, size);
     data.resize(stride * size);
     UniqueCPtr<cairo_surface_t, cairo_surface_destroy> image;
     image.reset(cairo_image_surface_create_for_data(
