@@ -13,13 +13,10 @@
 #include "fcitx-config/configuration.h"
 #include "fcitx-config/iniparser.h"
 #include "fcitx-config/option.h"
-#include "fcitx-utils/event.h"
 #include "fcitx-utils/i18n.h"
-#include "fcitx-utils/log.h"
 #include "fcitx/addonfactory.h"
 #include "fcitx/addoninstance.h"
 #include "fcitx/addonmanager.h"
-#include "fcitx/focusgroup.h"
 #include "fcitx/instance.h"
 #include "fcitx/userinterface.h"
 #include "classicui_public.h"
@@ -43,7 +40,7 @@ inline constexpr std::string_view PlasmaThemeName = "plasma";
 
 class UIInterface {
 public:
-    UIInterface(std::string name) : name_(name) {}
+    UIInterface(std::string name) : name_(std::move(name)) {}
 
     const std::string &name() const { return name_; }
 
