@@ -6,7 +6,6 @@
  */
 
 #include <cstdio>
-#include <cstdlib>
 #include <cstring>
 #include "fcitx-utils/key.h"
 #include "fcitx-utils/keydata.h"
@@ -150,6 +149,10 @@ int main() {
 
     FCITX_INFO() << fcitx::Key::keySymToString(
         FcitxKey_Insert, fcitx::KeyStringFormat::Localized);
+    FCITX_ASSERT(fcitx::Key::keySymToUnicode(
+                     static_cast<fcitx::KeySym>(0x100fdd7)) == 0xfdd7);
+    FCITX_ASSERT(fcitx::Key::keySymToUnicode(
+                     static_cast<fcitx::KeySym>(0x120fdd7)) == 0);
 
     return 0;
 }
